@@ -719,7 +719,8 @@ bool CtActions::_parse_node_content_iter(const CtTreeIter& tree_iter, Glib::RefP
     if (s_state.newline_trick) {
         buff_start_iter = text_buffer->begin();
         Gtk::TextIter buff_step_iter = buff_start_iter;
-        if (buff_step_iter.forward_char()) text_buffer->erase(buff_start_iter, buff_step_iter);
+        (void)buff_step_iter.forward_char();
+        text_buffer->erase(buff_start_iter, buff_step_iter);
         if (restore_modified) text_buffer->set_modified(false);
     }
     if (s_state.replace_active && pattern_found)
@@ -931,7 +932,7 @@ std::pair<int, int> CtActions::_check_pattern_in_object_between(CtTreeIter tree_
     }
     if (!forward) std::swap(start_offset, end_offset);
 
-    std::list<CtAnchoredWidget*> obj_vec = tree_iter.get_embedded_pixbufs_tables_codeboxes(start_offset, end_offset);
+    std::list<CtAnchoredWidget*> obj_vec = tree_iter.get_anchored_widgets(start_offset, end_offset);
     if (!forward)
         std::reverse(obj_vec.begin(), obj_vec.end());
     for (auto element: obj_vec)
