@@ -247,7 +247,7 @@ Glib::ustring CtClipboard::rich_text_get_from_text_buffer_selection(CtTreeIter n
     int iter_sel_end_offset = iter_sel_end.get_offset();
     if (exclude_iter_sel_end)
         iter_sel_end_offset -= 1;
-    std::list<CtAnchoredWidget*> widget_vector = node_iter.get_embedded_pixbufs_tables_codeboxes(iter_sel_start_offset, iter_sel_end_offset);
+    std::list<CtAnchoredWidget*> widget_vector = node_iter.get_anchored_widgets(iter_sel_start_offset, iter_sel_end_offset);
 
     xmlpp::Document doc;
     auto root = doc.create_root_node("root");
@@ -328,7 +328,7 @@ void CtClipboard::_selection_to_clipboard(Glib::RefPtr<Gtk::TextBuffer> text_buf
     CtImage* pixbuf_target = nullptr;
     if (not pCodebox and node_syntax_high == CtConst::RICH_TEXT_ID and num_chars == 1)
     {
-        std::list<CtAnchoredWidget*> widget_vector = _pCtMainWin->curr_tree_iter().get_embedded_pixbufs_tables_codeboxes(iter_sel_start.get_offset(), iter_sel_end.get_offset());
+        std::list<CtAnchoredWidget*> widget_vector = _pCtMainWin->curr_tree_iter().get_anchored_widgets(iter_sel_start.get_offset(), iter_sel_end.get_offset());
         if (widget_vector.size() > 0)
         {
             if (CtImage* image = dynamic_cast<CtImage*>(widget_vector.front()))
@@ -662,10 +662,15 @@ void CtClipboard::_on_received_to_html(const Gtk::SelectionData& selection_data,
 // From Clipboard to Image
 void CtClipboard::_on_received_to_image(const Gtk::SelectionData& selection_data, Gtk::TextView* pTextView, bool)
 {
-    Glib::RefPtr<const Gdk::Pixbuf> pixbuf = selection_data.get_pixbuf();
-    Glib::ustring link = "";
-    _pCtMainWin->get_ct_actions()->image_insert_png(pTextView->get_buffer()->get_insert()->get_iter(), pixbuf->copy(), link, "");
-    pTextView->scroll_to(pTextView->get_buffer()->get_insert());
+    Glib::RefPtr<const Gdk::Pixbuf> rPixbuf = selection_data.get_pixbuf();
+    if (rPixbuf) {
+        Glib::ustring link = "";
+        _pCtMainWin->get_ct_actions()->image_insert_png(pTextView->get_buffer()->get_insert()->get_iter(), rPixbuf->copy(), link, "");
+        pTextView->scroll_to(pTextView->get_buffer()->get_insert());
+    }
+    else {
+        spdlog::debug("invalid image in clipboard");
+    }
 }
 
 // From Clipboard to URI list
