@@ -26,6 +26,8 @@
 #include <curl/curl.h>
 #include <spdlog/fmt/bundled/printf.h>
 #include <system_error>
+#include <utility>
+#include <unordered_map>
 
 #include "ct_filesystem.h"
 #include "ct_misc_utils.h"
@@ -37,6 +39,20 @@ namespace fs {
 
 static fs::path _exePath;
 static fs::path _portableConfigDir;
+static std::unordered_map<std::string, std::pair<std::string,std::string>> _alteredLocaleEnvVars;
+
+void _locale_env_vars_set_for_external_cmd(const bool isPre)
+{
+    for (const auto& currPair : _alteredLocaleEnvVars) {
+        (void)Glib::setenv(currPair.first, isPre ? currPair.second.first : currPair.second.second, true/*overwrite*/);
+    }
+}
+
+bool alter_locale_env_var(const std::string& key, const std::string& val)
+{
+    _alteredLocaleEnvVars[key] = std::make_pair(Glib::getenv(key), val);
+    return Glib::setenv(key, val, true/*overwrite*/);
+}
 
 void register_exe_path_detect_if_portable(const char* exe_path)
 {
@@ -177,32 +193,52 @@ void open_weblink(const std::string& link)
 #endif
 }
 
+void _open_path_with_default_app(const fs::path& file_or_folder_path)
+{
+    _locale_env_vars_set_for_external_cmd(true/*isPre*/);
+#ifdef _WIN32
+    // https://stackoverflow.com/questions/42442189/how-to-open-spawn-a-file-with-glib-gtkmm-in-windows
+    glong utf16text_len = 0;
+    g_autofree gunichar2* utf16text = g_utf8_to_utf16(file_or_folder_path.c_str(),
+                                                      (glong)Glib::ustring(file_or_folder_path.c_str()).bytes(),
+                                                      nullptr,
+                                                      &utf16text_len,
+                                                      nullptr);
+    ShellExecuteW(GetActiveWindow(), L"open", (LPCWSTR)utf16text, NULL, NULL, SW_SHOWDEFAULT);
+#elif defined(__APPLE__)
+    std::vector<std::string> argv = { "open", file_or_folder_path.string() };
+    Glib::spawn_async("", argv, Glib::SpawnFlags::SPAWN_SEARCH_PATH);
+#else
+    std::vector<std::string> argv = { "xdg-open", "file://" + file_or_folder_path.string() };
+    Glib::spawn_async("", argv, Glib::SpawnFlags::SPAWN_SEARCH_PATH);
+    // g_app_info_launch_default_for_uri(f_path.c_str(), nullptr, nullptr); // doesn't work on KDE
+#endif
+    _locale_env_vars_set_for_external_cmd(false/*isPre*/);
+}
+
 // Open Filepath with External App
 void open_filepath(const fs::path& filepath, bool open_folder_if_file_not_exists, CtConfig* config)
 {
     spdlog::debug("fs::open_filepath {}", filepath);
     if (config->filelinkCustomOn) {
         std::string cmd = fmt::sprintf(config->filelinkCustomAct, filepath.string());
+        _locale_env_vars_set_for_external_cmd(true/*isPre*/);
         const int retVal = std::system(cmd.c_str());
+        _locale_env_vars_set_for_external_cmd(false/*isPre*/);
         if (retVal != 0) {
             spdlog::error("system({}) returned {}", cmd, retVal);
         }
-    } else {
+    }
+    else {
         if (open_folder_if_file_not_exists && !fs::exists(filepath)) {
             open_folderpath(filepath, config);
-        } else if (!fs::exists(filepath)) {
+        }
+        else if (!fs::exists(filepath)) {
             spdlog::error("fs::open_filepath: file doesn't exist, {}", filepath.string());
             return;
-        } else {
-#ifdef _WIN32
-            glong utf16text_len = 0;
-            g_autofree gunichar2* utf16text = g_utf8_to_utf16(filepath.c_str(), (glong)Glib::ustring(filepath.c_str()).bytes(), nullptr, &utf16text_len, nullptr);
-            ShellExecuteW(GetActiveWindow(), L"open", (LPCWSTR)utf16text, NULL, NULL, SW_SHOWNORMAL);
-#else
-            std::vector<std::string> argv = { "xdg-open", "file://" + filepath.string() };
-            Glib::spawn_async("", argv, Glib::SpawnFlags::SPAWN_SEARCH_PATH);
-            // g_app_info_launch_default_for_uri(f_path.c_str(), nullptr, nullptr); // doesn't work on KDE
-#endif
+        }
+        else {
+            _open_path_with_default_app(filepath);
         }
     }
 }
@@ -213,24 +249,15 @@ void open_folderpath(const fs::path& folderpath, CtConfig* config)
     spdlog::debug("fs::open_folderpath {}", folderpath);
     if (config->folderlinkCustomOn) {
         std::string cmd = fmt::sprintf(config->folderlinkCustomAct, folderpath.string());
+        _locale_env_vars_set_for_external_cmd(true/*isPre*/);
         const int retVal = std::system(cmd.c_str());
+        _locale_env_vars_set_for_external_cmd(false/*isPre*/);
         if (retVal != 0) {
             spdlog::error("system({}) returned {}", cmd, retVal);
         }
-    } else {
-        // https://stackoverflow.com/questions/42442189/how-to-open-spawn-a-file-with-glib-gtkmm-in-windows
-#ifdef _WIN32
-        glong utf16text_len = 0;
-        g_autofree gunichar2* utf16text = g_utf8_to_utf16(folderpath.c_str(), (glong)Glib::ustring(folderpath.c_str()).bytes(), nullptr, &utf16text_len, nullptr);
-        ShellExecuteW(GetActiveWindow(), L"open", (LPCWSTR)utf16text, NULL, NULL, SW_SHOWDEFAULT);
-#elif defined(__APPLE__)
-        std::vector<std::string> argv = { "open", folderpath.string() };
-        Glib::spawn_async("", argv, Glib::SpawnFlags::SPAWN_SEARCH_PATH);
-#else
-        std::vector<std::string> argv = { "xdg-open", "file://" + folderpath.string() };
-        Glib::spawn_async("", argv, Glib::SpawnFlags::SPAWN_SEARCH_PATH);
-        // g_app_info_launch_default_for_uri(f_path.c_str(), nullptr, nullptr); // doesn't work on KDE
-#endif
+    }
+    else {
+        _open_path_with_default_app(folderpath);
     }
 }
 
@@ -284,7 +311,7 @@ std::uintmax_t remove_all(const path& dir)
 
 fs::path get_cherrytree_datadir()
 {
-    if (Glib::file_test(_CMAKE_BINARY_DIR, Glib::FILE_TEST_IS_DIR)) {
+    if (_exePath.parent_path() == fs::canonical(_CMAKE_BINARY_DIR)) {
         // we're running from the build sources
         return _CMAKE_SOURCE_DIR;
     }
@@ -303,10 +330,9 @@ fs::path get_cherrytree_datadir()
 
 fs::path get_cherrytree_localedir()
 {
-    std::string sources_po_dir = Glib::canonicalize_filename(Glib::build_filename(_CMAKE_SOURCE_DIR, "po"));
-    if (Glib::file_test(sources_po_dir, Glib::FILE_TEST_IS_DIR)) {
+    if (_exePath.parent_path() == fs::canonical(_CMAKE_BINARY_DIR)) {
         // we're running from the build sources
-        return sources_po_dir;
+        return Glib::canonicalize_filename(Glib::build_filename(_CMAKE_SOURCE_DIR, "po"));
     }
 #ifdef _WIN32
     // e.g. cherrytree_0.99.9_win64_portable\mingw64\bin\cherrytree.exe
